# circum-cam

![build](https://travis-ci.com/LumineerLabs/circum-cam.svg?branch=master) ![PyPI](https://img.shields.io/pypi/v/circum-cam)

Webcam + ML sensor plugin for [circum](https://github.com/LumineerLabs/circum).

## Install

```bash
pip3 install circum-cam
```

## Usage

```bash
```
